src/inc/net.h 1.34

1.34 2009/10/20 22:38:01 galt
keep http request together
Index: src/inc/net.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/inc/net.h,v
retrieving revision 1.33
retrieving revision 1.34
diff -b -B -U 4 -r1.33 -r1.34
--- src/inc/net.h	3 Mar 2009 08:09:46 -0000	1.33
+++ src/inc/net.h	20 Oct 2009 22:38:01 -0000	1.34
@@ -156,21 +156,20 @@
 void netHttpGet(struct lineFile *lf, struct netParsedUrl *npu,
 		boolean keepAlive);
 /* Send a GET request, possibly with Keep-Alive. */
 
-int netOpenHttpExt(char *url, char *method, boolean end);
-/* Return a file handle that will read the url.  If end is not
- * set then can send cookies and other info to returned file  */
+int netOpenHttpExt(char *url, char *method, char *optionalHeader);
+/* Return a file handle that will read the url.  optionalHeader
+ * may by NULL or may contain cookies and other info. */
 
-int netHttpConnect(char *url, char *method, char *protocol, char *agent);
+int netHttpConnect(char *url, char *method, char *protocol, char *agent, char *optionalHeader);
 /* Parse URL, connect to associated server on port,
  * and send most of the request to the server.  If
  * specified in the url send user name and password
- * too.  This does not send the final \r\n to finish
- * off the request, so that you can send cookies. 
- * Typically the "method" will be "GET" or "POST"
+ * too.  Typically the "method" will be "GET" or "POST"
  * and the agent will be the name of your program or
- * library.  Protocol is usually HTTP/1.0. */
+ * library. optionalHeader may be NULL or contain
+ * additional header lines such as cookie info. */
 
 int netHttpGetMultiple(char *url, struct slName *queries, void *userData,
 		       void (*responseCB)(void *userData, char *req,
 					  char *hdr, struct dyString *body));